@@ -11,8 +11,8 @@ from PIL import ImageTk,Image
 from tkinter import filedialog
 from os import path
 import GBARpy
-from MCPPicture import BeamSpot, gaussian_offset, import_config, import_image
-from MCPPicture import MCPParams as mcpp
+from GBARpy.MCPPicture import BeamSpot, gaussian_offset, import_config, import_image
+from GBARpy.MCPPicture import MCPParams as mcpp
 import pickle
 from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
 from matplotlib.figure import Figure
@@ -81,7 +81,8 @@ class MainWindow(tkinter.Tk):
         panel = tkinter.Label(self.frame0, image=img)
         panel.image = img
         panel.pack(side='right')
-
+        self.tk.call('wm', 'iconphoto', self._w, tkinter.PhotoImage(file=add))
+        self.iconphoto(False, tkinter.PhotoImage(file=add))
         
         ### Cadre 1 Importation de l'image
         self.frame1 = tkinter.Frame(self, width=400, height=400,
