@@ -6,7 +6,8 @@ Created on Thu Dec 10 15:07:10 2020
 @author: samuel.niang@cern.ch
 """
 
-from Main_window import MainWindow
-win = MainWindow()
+from GBARpy.Main_window import MainWindow
+
+win = MainWindow()            
 win.mainloop()
 win.quit()
